@@ -35,21 +35,24 @@ def make_counts(
 
         i = 0
         j = 0
+        reads = []
         for line in f.readlines():
             if i == 1:
-                results.append(
-                    pool.apply_async(
-                        Counts.process,
-                        (
-                            line,
-                            regex,
-                            library.get_iter(),
-                        ),
-                    )
-                )
+                reads.append(line)
                 j += 1
                 if j % 1000 == 0:
                     print(f"Processed {j} reads.")
+                    results.append(
+                        pool.apply_async(
+                            Counts.process,
+                            (
+                                line,
+                                regex,
+                                library.get_iter(),
+                            ),
+                        )
+                    )
+                    reads = []
             if i == 3:
                 i = 0
                 continue
@@ -64,8 +67,8 @@ def make_counts(
         if not result.ready():
             results.insert(0, result)
             continue
-        guide = result.get()
-        if guide is not None:
+        guides = result.get()
+        for guide in guides:
             i += 1
             counts.count_map[guide] += 1
             if i % 1000 == 0:
